% CODE RELATED TO THE PAPER 
% "Flow duration curves from surface reflectance in the Near In-frared band"
% AUTHOR: Angelica Tarpanelli
% AFFILIATION: National Research Council (CNR-IRPI)

clear
clc
close all
%%  -------------------------- Data Preparation ---------------------------
% the file "ground and satellite data" includes:
% Area = basin area for each station
% D_CM = date of the satellite passage over the river
% CM = satellite data (C/M) for each station coming from MODIS AQUA
%(MYD09A1 Version 6 product in Near Infrared in band 2, 841 - 876 nm)
% D_Q = daily date of the ground data of river discharge
% Q = daily river discharge recorder at ground stations
% D_Q8 = date of the ground data of river discharge sampled every 8 days
% Q8 = daily river discharge recorder at ground stations sampled every 8
% days
% sta = name of the stations used for the analysis
% Stations = name of the stations used for the analysis
% lonlat = longitude and latitude of the stations used for the analysis

load ground_satellite_data

%% --------------- division calibration/validation -----------------------

date_calin8d  = find(D_Q8==datenum('01-Jan-2003'));
date_calin    = find(D_Q==datenum('01-Jan-2003'));

date_calfin8d = find(D_Q8==datenum('27-Dec-2015'));
date_calfin   = find(D_Q==datenum('27-Dec-2015'));

date_valin8d  = find(D_Q8==datenum('01-Jan-2016'));
date_valin    = find(D_Q==datenum('01-Jan-2016'));

date_valfin8d = find(D_Q8==datenum('27-Dec-2019'));
date_valfin   = find(D_Q==datenum('27-Dec-2019'));

ID=1:13; % possibility to select only some stations

D_Q8cal  = D_Q8(date_calin8d:date_calfin8d,1);
Q8cal    = Q8(date_calin8d:date_calfin8d,ID);

D_Q8val  = D_Q8(date_valin8d:date_valfin8d,1);
Q8val    = Q8(date_valin8d:date_valfin8d,ID);

D_Qcal   = D_Q(date_calin:date_calfin,1);
Qcal     = Q(date_calin:date_calfin,ID);

D_Qval   = D_Q(date_valin:date_valfin,1);
Qval     = Q(date_valin:date_valfin,ID);

D_CMcal  = D_CM(date_calin8d:date_calfin8d,1);
CMcal    = CM(date_calin8d:date_calfin8d,ID);

D_CMval  = D_CM(date_valin8d:date_valfin8d,1);
CMval    = CM(date_valin8d:date_valfin8d,ID);

%% -------------------------- Statistical Analysis -----------------------
Rpearson  = NaN(length(ID),1);
Rspearman = NaN(length(ID),1);
RMSE      = NaN(length(ID),1);
rRMSE     = NaN(length(ID),1);
NRMSE     = NaN(length(ID),1);
NS        = NaN(length(ID),1);
Qsim1     = NaN(size(CM));
mean_obs = NaN(1,length(ID));

for ii=1:length(ID)
 
    [Rpearson(ii,1),pval1(ii,1)] = corr(Q8(:,ID(ii)),CM(:,ID(ii)),'rows','complete');
    Rspearman(ii,1)= corr(Q8(:,ID(ii)),CM(:,ID(ii)),'Type','Spearman','rows','complete');
    CM_QQ          = rem_nan([CM(:,ID(ii)),Q8(:,ID(ii))]); % remove NaN from the time series
    Qsim1(:,ii)    = feval(fit(CM_QQ(:,1),CM_QQ(:,2),'poly2'),CM(:,ID(ii)));
    RMSE(ii,1)     = (nanmean((Q8(:,ID(ii))-Qsim1(:,ii)).^2).^0.5)';
    rRMSE(ii,1)    = RMSE(ii,1)./nanmean(Q8(:,ID(ii)));
    NRMSE(ii,1)    = RMSE(ii,1)./(nanmax(Q8(:,ID(ii)))-nanmin(Q8(:,ID(ii))));
    NS(ii,1)       = 1-nansum((Q8(:,ID(ii))-Qsim1(:,ii)).^2)./nansum((Q8(:,ID(ii))-nanmean(Q8(:,ID(ii)))).^2);
    mean_obs(1,ii)= nanmean(Q8(:,ID(ii)));
end

T = table(Rpearson,Rspearman,RMSE,rRMSE,NRMSE,NS,pval1,'RowNames',Stations);
display(T)
clear CM_QQ Rpearson Rspearman RMSE rRMSE NRMSE NS mean_obs ii pval1

%% ----- BUILDING OF THE FDC AND THE RDC IN CALIBRATION AND VALIDATION -----

DC_D_OBS      = NaN(length(D_Q),length(ID));
DC_Q_OBS      = NaN(length(D_Q),length(ID));
DCcal_D_OBS   = NaN(length(D_Qcal),length(ID));
DCcal_Q_OBS   = NaN(length(D_Qcal),length(ID));
DC8cal_D_OBS  = NaN(length(D_Q8cal),length(ID));
DC8cal_Q_OBS  = NaN(length(D_Q8cal),length(ID));
DC8val_D_OBS  = NaN(length(D_Q8val),length(ID));
DC8val_Q_OBS  = NaN(length(D_Q8val),length(ID));

DC8_CM_SAT    = NaN(length(D_CM),length(ID));
DC8_D_SAT     = NaN(length(D_CM),length(ID));
DC8cal_CM_SAT = NaN(length(D_CMcal),length(ID));
DC8cal_D_SAT  = NaN(length(D_CMcal),length(ID));
DC8val_CM_SAT = NaN(length(D_CMval),length(ID));
DC8val_D_SAT  = NaN(length(D_CMval),length(ID));

for ii=1:length(ID)
    
    % FDC OF THE DAILY DISCHARGE IN THE ENTIRE PERIOD(CAL+VAL)
    serie1_Q   = rem_nan([D_Q,Q(:,ID(ii))]);
    DC_Q       = sort(serie1_Q(:,2),'descend');
    f_DC_Q     = (((1:length(DC_Q)))./(length(DC_Q)+1))';
        
    % FDC OF THE DAILY DISCHARGE DURING CALIBRATION PERIOD
    serie2_Q   = rem_nan([D_Qcal,Qcal(:,ii)]);
    DC_Qcal    = sort(serie2_Q(:,2),'descend');
    f_DC_Qcal  = (((1:length(DC_Qcal)))./(length(DC_Qcal)+1))';
    
    % FDC OF THE 8-DAY DISCHARGE DURING THE CALIBRATION PERIOD
    serie3_Q8  = rem_nan([D_Q8cal,Q8cal(:,ii)]);
    DC_Q8cal   = sort(serie3_Q8(:,2),'descend');
    f_DC_Q8cal = (((1:length(DC_Q8cal)))./(length(DC_Q8cal)+1))';
    
    % FDC OF THE 8-DAY DISCHARGE DURING THE VALIDATION PERIOD
    serie4_Q8  = rem_nan([D_Q8val,Q8val(:,ii)]);
    DC_Q8val   = sort(serie4_Q8(:,2),'descend');
    f_DC_Q8val = (((1:length(DC_Q8val)))./(length(DC_Q8val)+1))';
    
    % RDC OF THE SATELLITE C/M IN THE ENTIRE PERIOD(CAL+VAL)
    serie1_CM  = rem_nan([D_CM,CM(:,ID(ii))]);
    DC_CM      = sort(serie1_CM(:,2),'descend');
    f_DC_CM    = (((1:length(DC_CM)))./(length(DC_CM)+1))';
    
    % RDC OF THE SATELLITE C/M IN THE CALIBRATION PERIOD
    serie2_CM  = rem_nan([D_CMcal,CMcal(:,ii)]);
    DC_CMcal   = sort(serie2_CM(:,2),'descend');
    f_DC_CMcal = (((1:length(DC_CMcal)))./(length(DC_CMcal)+1))';
    
    % RDC OF THE SATELLITE C/M IN THE VALIDATION PERIOD
    serie3_CM  = rem_nan([D_CMval,CMval(:,ii)]);
    DC_CMval   = sort(serie3_CM(:,2),'descend');
    f_DC_CMval = (((1:length(DC_CMval)))./(length(DC_CMval)+1))';
    
    % SAVE THE FDC AND RDC MATRIX 
    DC_Q_OBS(1:length(DC_Q),ii) = DC_Q;
    DC_D_OBS(1:length(DC_Q),ii) = f_DC_Q;
    DCcal_Q_OBS(1:length(DC_Qcal),ii) = DC_Qcal;
    DCcal_D_OBS(1:length(DC_Qcal),ii) = f_DC_Qcal;
    DC8cal_Q_OBS(1:length(DC_Q8cal),ii) = DC_Q8cal;
    DC8cal_D_OBS(1:length(DC_Q8cal),ii) = f_DC_Q8cal;
    DC8val_Q_OBS(1:length(DC_Q8val),ii) = DC_Q8val;
    DC8val_D_OBS(1:length(DC_Q8val),ii) = f_DC_Q8val;
    
    DC8_CM_SAT(1:length(DC_CM),ii) = DC_CM;
    DC8_D_SAT(1:length(DC_CM),ii) = f_DC_CM;
    DC8cal_CM_SAT(1:length(DC_CMcal),ii) = DC_CMcal;
    DC8cal_D_SAT(1:length(DC_CMcal),ii) = f_DC_CMcal;
    DC8val_CM_SAT(1:length(DC_CMval),ii) = DC_CMval;
    DC8val_D_SAT(1:length(DC_CMval),ii) = f_DC_CMval;   
    
    
clear serie1_Q DC_Q f_DC_Q serie2_Q DC_Qcal f_DC_Qcal serie3_Q8 DC_Q8cal 
clear f_DC_Q8cal serie4_Q8 DC_Q8val f_DC_Q8val serie1_CM DC_CM f_DC_CM 
clear serie2_CM DC_CMcal f_DC_CMcal serie3_CM DC_CMval f_DC_CMval
end

%% ------------ Figure 4 of the paper: FDC of the river discharge --------
figure(1)
set(gcf,'Position',[150 150 1400 800],'Paperpositionmode','manual','Papersize',[28 10],'Color','white')
yy=[0.85;0.72;0.59;0.46;0.33;0.20;0.07];
xx1=[0.05;0.55]; xx2=[0.30;0.80];
WH=[0.19 0.12];

for ii=1:7
    Pos(ii*2-1:2*ii,1:4)=[repmat(xx1,1,1) repmat(yy(ii),2,1) repmat(WH,2,1)];
    Pos2(ii*2-1:2*ii,1:4)=[repmat(xx2,1,1) repmat(yy(ii),2,1) repmat(WH,2,1)];
end

for ii=1:length(ID)

    % ESTIMATION OF THE ERRORS BETWEEN FDC_tot vs FDC_cal AND BETWEEN FDC_cal vs FDC_cal(8-days)
    
    XX=rem_nan([DC_D_OBS(:,ii),DC_Q_OBS(:,ii)]);
    D_XX=rem_nan([DCcal_D_OBS(:,ii),DCcal_Q_OBS(:,ii)]);
    DC_Q_tempocal=interp1(XX(:,1),XX(:,2),D_XX(:,1));
    bias1=D_XX(:,2)-DC_Q_tempocal;
    
    YY=rem_nan([DCcal_D_OBS(:,ii),DCcal_Q_OBS(:,ii)]);
    D_YY=rem_nan([DC8cal_D_OBS(:,ii),DC8cal_Q_OBS(:,ii)]);
    DC_Qcal_tempocal8=interp1(YY(:,1),YY(:,2),D_YY(:,1));
    bias2=DC_Qcal_tempocal8-D_YY(:,2);
    
    % ------------- TEST of Kolmogorov-Smirnov ---------------------------
    
    [test_decision1(ii,1),pvalue1(ii,1), ks2stat1(ii,1)] = kstest2(DCcal_Q_OBS(:,ii),DC_Q_OBS(:,ii),'Alpha',0.01);
    [test_decision2(ii,1),pvalue2(ii,1), ks2stat2(ii,1)] = kstest2(DCcal_Q_OBS(:,ii),DC8cal_Q_OBS(:,ii),'Alpha',0.01);

    % ---------------------------- FIGURE 4 -----------------------------
    hh(1) = axes('Position',Pos(ii,:));
    hold on
    plot(DCcal_D_OBS(:,ii)*100,DCcal_Q_OBS(:,ii)./10000,'-.','Color',[0.6,0.6,0.6],'LineWidth',2)
    plot(DC_D_OBS(:,ii)*100,DC_Q_OBS(:,ii)./10000,'-.','Color',[0.2,0.8,0.6],'LineWidth',2)
    plot(DC8cal_D_OBS(:,ii)*100,DC8cal_Q_OBS(:,ii)./10000,'-.','Color',[0.00,0.45,0.74],'LineWidth',2)
    grid on
    box on
    if ii~=12 && ii~=13
        set(gca,'xticklabel','')
    end
    
    if ii==12
        legend('FDC_c_a_l (2003-2015)','FDC_t_o_t (2003-2019)',...
            'FDC_c_a_l 8-day','Location','SouthOutSide')
        xlabel('Duration [%]')
    end
    
    axis([0 100 0 1.05.*DC_Q_OBS(1,ii)./10000])
    if ii==13, xlabel('Duration [%]'), end
    if ii==7, ylabel('Discharge [m^3/s] *10^4'), end
    if ii==8, ylabel('Discharge [m^3/s] *10^4'), end
    set(gca,'FontSize',13)
    text(95,0.90.*(DC_Q_OBS(1,ii)./10000),Sta{ii},...
        'HorizontalAlignment','right',...
        'FontSize',12)
    
    hh(2) = axes('Position',Pos2(ii,:));
    
    hold on
    plot(D_XX(:,1)*100,bias1./DC_Q_tempocal.*100,'-.','Color',[0.2,0.8,0.6],'LineWidth',2)
    plot(D_YY(:,1)*100,bias2./DC_Qcal_tempocal8.*100,'-.','Color',[0.00,0.45,0.74],'LineWidth',2)
    grid on
    box on
    axis([0 100 -45 25])
    if ii~=12 && ii~=13
        set(gca,'xticklabel','')
    end
    
    if ii==12
        legend('FDC_c_a_l vs FDC_t_o_t',...
            'FDC_c_a_l vs FDC_8_-_d_a_y',...
            'Location','SouthOutSide')
        xlabel('Duration [%]')
    end
    
    if ii==13, xlabel('Duration [%]'), end
    if ii==7, ylabel('Percentage Error in discharge'), end
    if ii==8, ylabel('Percentage Error in discharge'), end
    set(gca,'FontSize',13)
clear XX D_XX YY D_YY bias1 bias2 DC_Qcal_tempocal8 DC_Q_tempocal
end
% export_fig Figure_4REV -r150 -png -q60

%% ------------ Figure 5 of the paper: RDC of the C/M --------------------
figure(2)
set(gcf,'Position',[150 150 1400 800],'Paperpositionmode','manual','Papersize',[28 10],'Color','white')
yy=[0.85;0.72;0.59;0.46;0.33;0.20;0.07];
xx1=[0.05;0.55]; xx2=[0.30;0.80];
WH=[0.19 0.12];

for ii=1:7
    Pos(ii*2-1:2*ii,1:4)=[repmat(xx1,1,1) repmat(yy(ii),2,1) repmat(WH,2,1)];
    Pos2(ii*2-1:2*ii,1:4)=[repmat(xx2,1,1) repmat(yy(ii),2,1) repmat(WH,2,1)];
end

for ii=1:length(ID)
    
    % ESTIMATION OF THE ERRORS BETWEEN RDC_tot vs RDC_cal(8-days)
    XX=rem_nan([DC8_D_SAT(:,ii),DC8_CM_SAT(:,ii)]);
    D_XX=rem_nan([DC8cal_D_SAT(:,ii),DC8cal_CM_SAT(:,ii)]);
    DC_CM_tempocal=interp1(XX(:,1),XX(:,2),D_XX(:,1));
    bias3=D_XX(:,2)-DC_CM_tempocal;

    % ------------- TEST of Kolmogorov-Smirnov ---------------------------
    [test_decision3(ii,1),pvalue3(ii,1), ks2stat3(ii,1)] = kstest2(D_XX(:,2),XX(:,2),'Alpha',0.01);
    
    % ---------------------------- FIGURE 5 ------------------------------
    hh(1) = axes('Position',Pos(ii,:));
    
    hold on
    plot(XX(:,1).*100,XX(:,2),'-.','Color',[0.75,0.23,0.10],'LineWidth',2)
    plot(D_XX(:,1).*100,D_XX(:,2),'-.','Color',[0.95,0.43,0.10],'LineWidth',2)
    grid on
    box on
    if ii~=12 && ii~=13
        set(gca,'xticklabel','')
    end

    if ii==13
        legend('RDC_t_o_t (2003-2019)','RDC_c_a_l (2003-2015)',...
            'Location','SouthEastOutSide')
        xlabel('Duration [%]')
    end
    
    axis([0 100 0 1.05.*max(DC8_CM_SAT(:,ii))])
    if ii==12, xlabel('Duration [%]'), end
    if ii==7, ylabel('CM'), end
    if ii==8, ylabel('CM'), end
    set(gca,'FontSize',13)
    text(95,0.90.*(DC8_CM_SAT(1,ii)),Sta{ii},...
        'HorizontalAlignment','right',...
        'FontSize',12)
    
    hh(2) = axes('Position',Pos2(ii,:));
    
    hold on
    plot(D_XX(:,1)*100,bias3./DC_CM_tempocal.*100,'-.','Color',[0.55,0.03,0.10],'LineWidth',2)
    grid on
    box on
    axis([0 100 -30 10])
    if ii~=12 && ii~=13
        set(gca,'xticklabel','')
    end
    
    if ii==12
        legend('RDC_c_a_l vs RDC_t_o_t',...
            'Location','SouthOutSide')
        xlabel('Duration [%]')
    end

    if ii==13, xlabel('Duration [%]'), end
    if ii==7, ylabel('Percentage Error in C/M'), end
    if ii==8, ylabel('Percentage Error in C/M'), end
    set(gca,'FontSize',13)
    
    clear serie1_CM serie2_CM DC_CM DC_CMcal f_DC_CM f_DC_CMcal bias3
end
% export_fig Figure5 -r150 -png -q60

%% ---------- RELATIONSHIP Q VS C/M IN THE CALIBRATION PERIOD ------------

figure(3)
set(gcf,'Position',[150 150 1200 800],'Paperpositionmode','manual','Papersize',[28 10],'Color','white')
yy=[0.79;0.55;0.31;0.07];
xx=[0.08; 0.31; 0.55; 0.78];
WH=[0.20,0.20];

Rp_fit          = NaN(length(ID),1);
pval            = NaN(length(ID),1);
Rs_fit          = NaN(length(ID),1);
RMSE_fit        = NaN(length(ID),1);
rRMSE_fit       = NaN(length(ID),1);
NRMSE_fit       = NaN(length(ID),1);
NS_fit          = NaN(length(ID),1);
NS_fitval       = NaN(length(ID),1);
Qsim_cal        = NaN(length(D_CMcal),length(ID));
Qsim_val        = NaN(length(D_CMval),length(ID));
DCsim_cal       = NaN(length(D_CMcal),length(ID));
DCsim_val       = NaN(length(D_CMval),length(ID));
Perc_durata_cal = NaN(length(D_CMcal),length(ID));
Perc_durata_val = NaN(length(D_CMval),length(ID));

for ii=1:4
    Pos(ii*4-3:ii*4,1:4)=[xx repmat(yy(ii),4,1) repmat(WH,4,1)];
end

for ii=1:length(ID)
    
    %  ----------------------- Fit the duration curve --------------------
    DCobs=rem_nan([DC8cal_D_OBS(:,ii),DC8cal_Q_OBS(:,ii)]);
    DCsat=rem_nan([DC8cal_D_SAT(:,ii),DC8cal_CM_SAT(:,ii)]);
       
    p_interpCM = interp1(DCsat(:,1),DCsat(:,2),0.001:0.015:0.9999,'linear','extrap');
    p_interpQ = interp1(DCobs(:,1),DCobs(:,2),0.001:0.015:0.9999,'linear','extrap');

    % ----------------- Simulated Flow Duration Curve --------------------
    DCsim_cal(1:length(DC8cal_CM_SAT(:,ii)),ii) = feval(fit(p_interpCM',p_interpQ','smoothingspline'),DC8cal_CM_SAT(:,ii));
    DCsim_val(1:length(DC8val_CM_SAT(:,ii)),ii) = feval(fit(p_interpCM',p_interpQ','smoothingspline'),DC8val_CM_SAT(:,ii));
    
    % ------------------------- Simulated Discharge ----------------------
    Qsim_cal(1:length(CMcal(:,ii)),ii) = feval(fit(p_interpCM',p_interpQ','smoothingspline'),CMcal(:,ii));
    Qsim_val(1:length(CMval(:,ii)),ii) = feval(fit(p_interpCM',p_interpQ','smoothingspline'),CMval(:,ii));
    
    % -------------------- Frequency of the C7M series -------------------
    Perc_durata_cal(:,ii)=interp1(p_interpCM,0.001:0.015:0.9999,CMcal(:,ii));
    Perc_durata_val(:,ii)=interp1(p_interpCM,0.001:0.015:0.9999,CMval(:,ii));
    
    % ---------------------------- FIGURE --------------------------------
    hh(1) = axes('Position',Pos(ii,:));
    hold on
    plot(p_interpCM',p_interpQ'./10000,'o','Color',[0.7 0.7 0.9],'MarkerSize',5,'MarkerFaceColor',[0.7 0.7 0.9])
    plot(DC8cal_CM_SAT(:,ii),DCsim_cal(:,ii)./10000,'k--','LineW',2)
    grid on, box on
    MM=max(nanmax(DCsim_cal(:,ii)),nanmax(p_interpQ));
    
    axis([min(p_interpCM) max(p_interpCM) min(p_interpQ)./10000 MM./10000])
    
    if ii==13
        legend('pair Q - C/M','fit',...
            'Location','SouthEastOutSide')
        xlabel('C/M')
    end
    
    if ii==11 || ii==10 || ii==12, xlabel('C/M'), end
    if ii==5, ylabel('Discharge [m^3/s]*10^4'), end
    
    text(min(p_interpCM)*1.1,0.90.*MM./10000,Sta{ii},...
        'HorizontalAlignment','left',...
        'FontSize',13)
    set(gca,'FontSize',12)

    [Rp_fit(ii,1),pval(ii,1)]    = corr(DC8cal_Q_OBS(:,ii),DCsim_cal(:,ii),'rows','complete');
    Rs_fit(ii,1)    = corr(DC8cal_Q_OBS(:,ii),DCsim_cal(:,ii),'Type','Spearman','rows','complete');
    RMSE_fit(ii,1)  = (nanmean((DC8cal_Q_OBS(:,ii)-DCsim_cal(:,ii)).^2).^0.5)';
    rRMSE_fit(ii,1) = RMSE_fit(ii,1)./nanmean(DC8cal_Q_OBS(:,ii)).*100;
    NRMSE_fit(ii,1) = RMSE_fit(ii,1)./(nanmax(DC8cal_Q_OBS(:,ii))-nanmin(DC8cal_Q_OBS(:,ii))).*100;
    NS_fit(ii,1)    = 1-nansum((DC8cal_Q_OBS(:,ii)-DCsim_cal(:,ii)).^2)./nansum((DC8cal_Q_OBS(:,ii)-nanmean(DC8cal_Q_OBS(:,ii))).^2);
    NS_fitval(ii,1) = 1-nansum((DC8val_Q_OBS(:,ii)-DCsim_val(:,ii)).^2)./nansum((DC8val_Q_OBS(:,ii)-nanmean(DC8val_Q_OBS(:,ii))).^2);
    
end
PERFrel=[Rp_fit,Rs_fit,RMSE_fit./1000,rRMSE_fit,NRMSE_fit,NS_fit,NS_fitval,pval];
display(PERFrel)
% export_fig Relationship -r150 -png -q60

%% ------------------------- FIGURE 6: CALIBRATION -----------------------
figure(4)
set(gcf,'Position',[150 150 1200 800],'Paperpositionmode','manual','Papersize',[28 10],'Color','white')
yy=[0.85;0.72;0.59;0.46;0.33;0.20;0.07];
xx=[0.08;0.55];
WH=[0.40,0.12];

Rp_fit    = NaN(length(ID),1);
pval      = NaN(length(ID),1);
slopec     = NaN(length(ID),2);
Rs_fit    = NaN(length(ID),1);
RMSE_fit  = NaN(length(ID),1);
rRMSE_fit = NaN(length(ID),1);
NRMSE_fit = NaN(length(ID),1);
NS_fit    = NaN(length(ID),1);

for ii=1:7
    Pos(ii*2-1:2*ii,1:4)=[repmat(xx,1,1) repmat(yy(ii),2,1) repmat(WH,2,1)];
end

for ii=1:length(ID)
    
    hh(1) = axes('Position',Pos(ii,:));
    hold on

    plot(D_Q8cal,Q8cal(:,ii)./10000,'-')
    plot(D_CMcal,Qsim_cal(:,ii)./10000,'-')
    MM=max(max(Qsim_cal(:,ii)),max(Q8cal(:,ii)));
    grid on, box on
    axis([datenum('31-Dec-2002') datenum('01-Jan-2016') 0 MM./10000])
    datetick
    if ii~=12 && ii~=13
        set(gca,'xticklabel','')
    end
    
    if ii==13
        legend('Ground Observed','Simulated',...
            'Location','SouthEastOutSide')
        xlabel('Time [8 days]')
    end
    
    if ii==12, xlabel('Time [8 days]'), end
    if ii==7, ylabel('Discharge [m^3/s]*10^4'), end
    set(gca,'FontSize',13)
    
    text(datenum('01-Feb-2003'),0.90.*MM./10000,Sta{ii},...
        'HorizontalAlignment','left',...
        'FontSize',12)
    
     if ii==13 || ii==12
        set(gca,'xticklabel',{'2003','','2005','','2007','','2009','','2011','','2013','','2015',''})
    end
    
    [Rp_fit(ii,1),pval(ii,1)] = corr(Q8cal(:,ii),Qsim_cal(:,ii),'rows','complete');
    Rs_fit(ii,1)    = corr(Q8cal(:,ii),Qsim_cal(:,ii),'Type','Spearman','rows','complete');
    RMSE_fit(ii,1)  = (nanmean((Q8cal(:,ii)-Qsim_cal(:,ii)).^2).^0.5)';
    rRMSE_fit(ii,1) = RMSE_fit(ii,1)./nanmean(Q8cal(:,ii)).*100;
    NRMSE_fit(ii,1) = RMSE_fit(ii,1)./(nanmax(Q8cal(:,ii))-nanmin(Q8cal(:,ii))).*100;
    NS_fit(ii,1)    = 1-nansum((Q8cal(:,ii)-Qsim_cal(:,ii)).^2)./nansum((Q8cal(:,ii)-nanmean(Q8cal(:,ii))).^2);
    XX=rem_nan([Q8cal(:,ii),Qsim_cal(:,ii)]);
    slopec (ii,1:2)= polyfit(XX(:,1),XX(:,2),1);
    
end
PERFcal=[Rp_fit,Rs_fit,RMSE_fit./1000,rRMSE_fit,NRMSE_fit,NS_fit,pval,slopec(:,1)];
display(PERFcal)
% export_fig Figure6Rev -r150 -png -q60

%% ------------------------- FIGURE 6: VALIDATION ------------------------
figure(5)
set(gcf,'Position',[150 150 1200 800],'Paperpositionmode','manual','Papersize',[28 10],'Color','white')
yy=[0.85;0.72;0.59;0.46;0.33;0.20;0.07];
xx=[0.08;0.55];
WH=[0.40,0.12];

Rp_fit    = NaN(length(ID),1);
pval      = NaN(length(ID),1);
slopev     = NaN(length(ID),2);
Rs_fit    = NaN(length(ID),1);
RMSE_fit  = NaN(length(ID),1);
rRMSE_fit = NaN(length(ID),1);
NRMSE_fit = NaN(length(ID),1);
NS_fit    = NaN(length(ID),1);

for ii=1:7
    Pos(ii*2-1:2*ii,1:4)=[repmat(xx,1,1) repmat(yy(ii),2,1) repmat(WH,2,1)];
end

for ii=1:length(ID)
  
    [Rp_fit(ii,1),pval(ii,1)]   = corr(Q8val(:,ii),Qsim_val(:,ii),'rows','complete');
    Rs_fit(ii,1)    = corr(Q8val(:,ii),Qsim_val(:,ii),'Type','Spearman','rows','complete');
    RMSE_fit(ii,1)  = (nanmean((Q8val(:,ii)-Qsim_val(:,ii)).^2).^0.5)';
    rRMSE_fit(ii,1) = RMSE_fit(ii,1)./nanmean(Q8val(:,ii)).*100;
    NRMSE_fit(ii,1) = RMSE_fit(ii,1)./(nanmax(Q8val(:,ii))-nanmin(Q8val(:,ii))).*100;
    NS_fit(ii,1)    = 1-nansum((Q8val(:,ii)-Qsim_val(:,ii)).^2)./nansum((Q8val(:,ii)-nanmean(Q8val(:,ii))).^2);
    XX=rem_nan([Q8val(:,ii),Qsim_val(:,ii)]);
    slopev (ii,1:2)= polyfit(XX(:,1),XX(:,2),1);
    
    hh(1) = axes('Position',Pos(ii,:));
    hold on
    
    plot(D_Q8val,Q8val(:,ii)./10000,'-')
    plot(D_Q8val,Qsim_val(:,ii)./10000,'-')
    MM=max(max(Qsim_val(:,ii)),max(Q8val(:,ii)));
    axis([datenum('01-Jan-2016') datenum('01-Jan-2020') 0 MM./10000])
    labelval={'2016','2017','2018','2019','2020'};
    datetick
    grid on
    box on
    if ii~=12 && ii~=13
        set(gca,'xticklabel','')
    end
    
    if ii==13
        legend('Ground Observed','Simulated',...
            'Location','SouthEastOutSide')
        xlabel('Time [8 days]')
    end
    
    if ii==12, xlabel('Time [8 days]'), end
    if ii==7, ylabel('Discharge [m^3/s]*10^4'), end
    set(gca,'FontSize',13)
    
    text(datenum('01-Feb-2016'),0.90.*MM./10000,Sta{ii},...
        'HorizontalAlignment','left',...
        'FontSize',12)
    
    if ii==13 || ii==12
        set(gca,'xticklabel',labelval)
    end
    
    clear f_DC_Qcal f_DC_Q8cal bias1 bias2 f_DC_Qcal DC_Qcal f_DC_Qtot DC_Q f_DC_Q8cal DC_Q8cal f_DC_CMcal DC_CMcal f_DC_CM DC_CM
end

PERFval=[Rp_fit,Rs_fit,RMSE_fit./100,rRMSE_fit,NRMSE_fit,NS_fit,pval,slopev(:,1)];
display(PERFval)
% export_fig Figure7Rev -r150 -png -q60

%% -------- FIGURE 8: FDC OF THE SIMULATED DISCHARGE IN VALIDATION -------

figure(7)
set(gcf,'Position',[150 150 1200 800],'Paperpositionmode','manual','Papersize',[28 10],'Color','white')
yy=[0.79;0.55;0.31;0.07];
xx=[0.08; 0.31; 0.55; 0.78];
WH=[0.20,0.20];

Dtest     = D_Q8val;
Qtest     = Q8val;
Dall      = D_Q;
Qall      = Q;
YY_obs    = unique(year(Dtest));
YY_obsall = unique(year(Dall));
ks2stat   = NaN(length(ID),1); test_decision=ks2stat; pvalue=ks2stat;

for ii=1:4
    Pos(ii*4-3:ii*4,1:4)=[xx repmat(yy(ii),4,1) repmat(WH,4,1)];
end

for ii=1:length(ID)

    DC_Qann    = NaN(366,length(YY_obs));
    f_DC_Qann  = NaN(366,length(YY_obs));
    DC_QannA   = NaN(366,length(YY_obsall));
    f_DC_QannA = NaN(366,length(YY_obsall));
    
    if ii~= 5
        serie=rem_nan([D_Q8val,Qsim_val(:,ii),Q8val(:,ii)]);
        DCval_Q_sim=sort(serie(:,2),'descend');
        DCval_Q_obs=sort(serie(:,3),'descend');
        f_DC_CMval2= (((1:length(serie(:,1))))./(length(serie(:,1))+1))';
        [test_decision(ii,1),pvalue(ii,1), ks2stat(ii,1)] = kstest2(DCval_Q_sim,DCval_Q_obs,'Alpha',0.01);
    else
        serie=rem_nan([D_Q8val,Qsim_val(:,ii)]);
        DCval_Q_sim=sort(serie(:,2),'descend');
        f_DC_CMval2= (((1:length(serie(:,1))))./(length(serie(:,1))+1))';
    end
    
    hh(1) = axes('Position',Pos(ii,:));
    hold on
    grid on
    box on
    
    for gg=1:length(YY_obs)
        IDG=find(year(Dtest)==YY_obs(gg));
        DD_ann=Dtest(IDG);
        Q_ann=Qtest(IDG,ii);
        serie9_Q=rem_nan([DD_ann,Q_ann]);
        serietemp=sort(serie9_Q(:,2),'descend');
        DC_Qann(1:length(serie9_Q(:,1)),gg)=sort(serie9_Q(:,2),'descend');
        f_DC_Qann(1:length(serie9_Q(:,1)),gg)= (((1:length(serietemp)))./(length(serietemp)+1))';
    end
    
    for gg1=1:length(YY_obsall)
        IDGall=find(year(Dall)==YY_obsall(gg1));
        DD_annall=Dall(IDGall);
        Q_annall=Qall(IDGall,ii);
        serieA_Q=rem_nan([DD_annall,Q_annall]);
        serietempA=sort(serieA_Q(:,2),'descend');
        DC_QannA(1:length(serieA_Q(:,1)),gg1)=sort(serieA_Q(:,2),'descend');
        f_DC_QannA(1:length(serieA_Q(:,1)),gg1)= (((1:length(serietempA)))./(length(serietempA)+1))';
        [CC]=plot(f_DC_QannA(:,gg1)*100,DC_QannA(:,gg1)./10000,'-.','Color',[0.85,0.85,0.85],'LineWidth',1);
    end
    
    [SIM]=plot(f_DC_CMval2*100,DCval_Q_sim./10000,'-','Color',[0.75,0.23,0.10],'LineWidth',2);
    if ii~= 5
        [OOB]=plot(f_DC_CMval2*100,DCval_Q_obs./10000,'--','Color',[0.00,0.45,0.74],'LineWidth',2);
    end
    if ii~=12 && ii~=13
        set(gca,'xticklabel','')
    end
    
    if ii==12
        legend([SIM,OOB,CC],'FDC_v_a_l sim (2016-2019)',...
            'FDC_v_a_l obs (2016-2019)','FDC_t_o_t annual (2003-2019)',...
         'Location','SouthOutSide')
    end
    axis([0 100 0 1.15.*DCval_Q_sim(1)./10000])
    
    if (ii==10) || (ii==11) || (ii==12) || (ii==13), xlabel('Duration [%]'), end
    if ii==9, ylabel('Discharge [m^3/s] *10^4'), end
    set(gca,'FontSize',13)
    text(95,0.99.*(DCval_Q_sim(1)./10000),Sta{ii},...
        'HorizontalAlignment','right',...
        'FontSize',12)
    
clear serie DCval_Q_sim DCval_Q_obs f_DC_CMval2 bands10 f_DC_Qann DC_Qann
end
% export_fig Figure8Rev -r150 -png -q60

%% ---------------- FIGURE 9: ERROR IN TERMS OF DURATION -----------------

figure(6)
set(gcf,'Position',[150 150 900 800],'Paperpositionmode','manual','Papersize',[28 10],'Color','white')
yy=[0.83;0.68;0.53;0.38;0.23;0.08]; yy1=repmat(yy,1,4);
xx=[0.10;0.55];
WH=[0.40 0.15];

for ii=1:6
    Pos(ii*2-1:2*ii,1:4)=[repmat(xx,1,1) repmat(yy(ii),2,1) repmat(WH,2,1)];
end

for count=1:length(ID)-1
    if count<5,ii=count;else, ii=count+1; end
        
    bias4=Qsim_cal(:,ii)-Q8cal(:,ii);
    bias5=Qsim_val(:,ii)-Q8val(:,ii);
    [Qval4,IDpos4]=nanmax(bias4);
    [Qval5,IDpos5]=nanmax(bias5);
    Qb4(ii,1)=Qval4./Q8cal(IDpos4,ii);
    Qb5(ii,1)=Qval5./Q8val(IDpos5,ii);
    
    hh(1) = axes('Position',Pos(count,:));
    hold on
    plot(Perc_durata_cal(:,ii).*100,bias4./10000,'o','Color',[0.10 0.13 0.55],'MarkerFaceColor',[0.10 0.33 0.85])
    plot(Perc_durata_val(:,ii).*100,bias5./10000,'o','Color',[0.55 0.13 0.10],'MarkerFaceColor',[0.85 0.33 0.10])
    grid on, box on
    axis([0 100 1.30.*min(bias5)./10000 1.30.*max(bias5)./10000])
   
    if ii~=12 && ii~=13
        set(gca,'xticklabel','')
    end
    
    if ii==12 || ii==13, xlabel('Duration [%]'), end
    if ii==6, ylabel('Error in discharge [m^3/s]*10^4'), end
    set(gca,'FontSize',13)
    
    text(90,0.90.*max(bias5)./10000,Sta{ii},...
        'HorizontalAlignment','right',...
        'FontSize',12)
    if ii==1
        legend('calibration','validation','Location','North')
    end
clear bias4 bias5
end
% export_fig Figure9Rev -r150 -png -q60
display([Qb4,Qb5])